@@ -6,12 +6,12 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '1.014';
+our $VERSION = '1.015';
 
-use Cwd        qw( realpath );
-use Encode     qw( encode decode );
-use File::Temp qw( tempfile );
-use List::Util qw( all );
+use Cwd              qw( realpath );
+use Encode           qw( encode decode );
+use File::Temp       qw( tempfile );
+use List::Util       qw( all );
 
 #use Clone                  qw( clone );
 use List::MoreUtils        qw( first_index );
@@ -21,7 +21,6 @@ use Term::Choose           qw();
 use Term::Choose::Util     qw( choose_multi );
 use Term::ReadLine::Simple qw();
 use Text::CSV              qw();
-use Text::ParseWords       qw( parse_line );
 
 use App::DBBrowser::Auxil;
 
@@ -165,32 +164,27 @@ sub __insert_into {
             }
         }
         else {
-            my ( $file, $sheet_idx );
-            if ( $input_mode eq 'Multirow' ) {
-                ( my $fh, $file ) = tempfile( DIR => $self->{info}{app_dir}, UNLINK => 1 , SUFFIX => '.csv' );
-                binmode $fh, ':encoding(' . $self->{opt}{insert}{encoding_csv_file} . ')';
+            if ( $input_mode eq 'Paste' ) {
+                my ( $fh, $file ) = tempfile( DIR => $self->{info}{app_dir}, UNLINK => 1 , SUFFIX => '.csv' );
+                binmode $fh, ':encoding(' . $self->{opt}{insert}{file_encoding} . ')';
                 $auxil->__print_sql_statement( $sql, $table, $sql_type );
                 print 'Multirow: ' . "\n";
                 # STDIN
-                while ( my $row = <STDIN> ) {
-                    print $fh $row;
-                }
+                print $fh do { local $/; <STDIN> };
                 seek $fh, 0, 0;
-                if ( $self->{opt}{insert}{csv_read} < 2 ) {
-                    $file = $fh;
-                }
-                ( $sql->{quote}{insert_into_args}, $sheet_idx ) = $self->__parse_file( $file );
-                if ( ! @{$sql->{quote}{insert_into_args}} ) {
-                    my $cm = Term::Choose->new( { prompt => 'Press ENTER' } );
-                    $cm->choose( [ 'empty sheet!' ] );
-                    if ( @{$self->{opt}{insert}{input_modes}} == 1 ) {
-                        $sql->{quote}{chosen_cols} = [];
-                        $sql->{print}{chosen_cols} = [];
-                        return;
+                if ( $self->{opt}{insert}{parse_mode} < 2 ) {
+                    ( $sql->{quote}{insert_into_args} ) = $self->__parse_file( $fh );
+                    if ( ! @{$sql->{quote}{insert_into_args}} ) {
+                        my $cm = Term::Choose->new( { %{$self->{info}{lyt_stop}}, prompt => 'Press ENTER' } );
+                        $cm->choose( [ 'empty file!' ] );
                     }
-                    next VALUES;
+                    $self->__filter_input( $sql, $table, $sql_type, $fh );
+                }
+                else {
+                    my $sheet_idx;
+                    ( $sql->{quote}{insert_into_args}, $sheet_idx ) = $self->__parse_file( $file );
+                    $self->__filter_input( $sql, $table, $sql_type, $file, $sheet_idx );
                 }
-                $self->__filter_input( $sql, $table, $sql_type, $file, $sheet_idx );
                 if ( ! @{$sql->{quote}{insert_into_args}} ) {
                     if ( @{$self->{opt}{insert}{input_modes}} == 1 ) {
                         $sql->{quote}{chosen_cols} = [];
@@ -201,14 +195,15 @@ sub __insert_into {
                 }
             }
             elsif ( $input_mode eq 'File' ) {
+                my ( $file );
                 FILE: while ( 1 ) {
                     my @files;
                     if ( $self->{opt}{insert}{max_files} && -e $self->{info}{input_files} ) {
                         open my $fh_in, '<', $self->{info}{input_files} or die $!;
-                        while ( my $f = <$fh_in> ) {
-                            chomp $f;
-                            next if ! -e $f;
-                            push @files, $f;
+                        while ( my $fl = <$fh_in> ) {
+                            chomp $fl;
+                            next if ! -e $fl;
+                            push @files, $fl;
                         }
                         close $fh_in;
                     }
@@ -261,8 +256,8 @@ sub __insert_into {
                                 shift @files;
                             }
                             open my $fh_out, '>', $self->{info}{input_files} or die $!;
-                            for my $f ( @files ) {
-                                print $fh_out $f . "\n";
+                            for my $fl ( @files ) {
+                                print $fh_out $fl . "\n";
                             }
                             close $fh_out;
                         }
@@ -270,28 +265,25 @@ sub __insert_into {
                     else {
                         $file = realpath encode 'locale_fs', $file;
                     }
-                    if ( $self->{opt}{insert}{csv_read} < 2 && -T $file ) {
-                        open my $fh, '<:encoding(' . $self->{opt}{insert}{encoding_csv_file} . ')', $file or die $!;
-                        $file = $fh;
+                    if ( $self->{opt}{insert}{parse_mode} < 2 && -T $file ) {
+                        open my $fh, '<:encoding(' . $self->{opt}{insert}{file_encoding} . ')', $file or die $!;
+                        ( $sql->{quote}{insert_into_args} ) = $self->__parse_file( $fh );
+                        if ( ! @{$sql->{quote}{insert_into_args}} ) {
+                            my $cm = Term::Choose->new( { %{$self->{info}{lyt_stop}}, prompt => 'Press ENTER' } );
+                            $cm->choose( [ 'empty file!' ] );
+                        }
+                        $self->__filter_input( $sql, $table, $sql_type, $fh );
+                        close $fh;
                     }
-                    ( $sql->{quote}{insert_into_args}, $sheet_idx ) = $self->__parse_file( $file );
-                    if ( ! defined $sql->{quote}{insert_into_args} ) {
-                        $sql->{quote}{insert_into_args} = [];
-                        next FILE;
-                    }
-                    if ( ! @{$sql->{quote}{insert_into_args}} ) {
-                        my $cm = Term::Choose->new( { %{$self->{info}{lyt_stop}}, prompt => 'Press ENTER' } );
-                        $cm->choose( [ 'empty file!' ] );
-                        next FILE;
-                    }
-                    $self->__filter_input( $sql, $table, $sql_type, $file, $sheet_idx );
-                    if ( ! @{$sql->{quote}{insert_into_args}} ) {
-                        next FILE;
+                    else {
+                        my $sheet_idx;
+                        ( $sql->{quote}{insert_into_args}, $sheet_idx ) = $self->__parse_file( $file );
+                        $self->__filter_input( $sql, $table, $sql_type, $file, $sheet_idx );
                     }
+                    next FILE if ! @{$sql->{quote}{insert_into_args}};
                     last FILE;
                 }
             }
-            close $file if ref $file eq 'GLOB';
             return;
         }
     }
@@ -299,31 +291,30 @@ sub __insert_into {
 
 
 sub __parse_file {
-    my ( $self, $file, $sheet_idx ) = @_;
-    if ( ref $file eq 'GLOB' ) {
-        seek $file, 0, 0;
+    my ( $self, $file_or_fh, $sheet_idx ) = @_;
+    if ( ref $file_or_fh eq 'GLOB' ) {
+        my $fh = $file_or_fh;
+        seek $fh, 0, 0;
         my $tmp = [];
-        if ( $self->{opt}{insert}{csv_read} == 0 ) {
+        if ( $self->{opt}{insert}{parse_mode} == 0 ) {
             my $csv = Text::CSV->new( { map { $_ => $self->{opt}{insert}{$_} } @{$self->{info}{csv_opt}} } );
-            while ( my $row = $csv->getline( $file ) ) {
+            while ( my $row = $csv->getline( $fh ) ) {
                 push @$tmp, $row;
             }
         }
         else {
-            while ( my $row = <$file> ) {
-                chomp $row;
-                push @$tmp, [ parse_line( $self->{opt}{insert}{delim}, $self->{opt}{insert}{keep}, $row ) ];
-                #push @$tmp, [ split $self->{opt}{insert}{delim}, $row ];
-            }
+            local $/;
+            push @$tmp, map { [ split /$self->{opt}{insert}{i_f_s}/ ] } split /$self->{opt}{insert}{i_r_s}/, <$fh>;
         }
         return $tmp;
     }
     else {
+        my $file = $file_or_fh;
         my $cm = Term::Choose->new( { %{$self->{info}{lyt_stop}}, prompt => 'Press ENTER' } );
         my $file_dc = decode( 'locale_fs', $file );
         if ( ! -e $file ) {
             $cm->choose( [ $file_dc . ' : file not found!' ] );
-            return;
+            return [];
         }
         if ( ! -s $file ) {
             $cm->choose( [ $file_dc . ' : file is empty!' ] );
@@ -331,20 +322,20 @@ sub __parse_file {
         }
         if ( ! -r $file ) {
             $cm->choose( [ $file_dc . ' : file is not readable!' ] );
-            return;
+            return [];
         }
         require Spreadsheet::Read;
         my $book = Spreadsheet::Read::ReadData( $file, cells => 0, attr => 0, rc => 1, strip => 0 );
         if ( ! defined $book ) {
             $cm->choose( [ $file_dc . ' : no book!' ] );
-            return;
+            return [];
+        }
+        elsif ( @$book < 2 ) { # first sheet in $book contains meta info
+            $cm->choose( [ $file_dc . ' : no sheets!' ] );
+            return [];
         }
         if ( $sheet_idx ) {
-            return [ Spreadsheet::Read::rows( $book->[$sheet_idx] ) ], $sheet_idx;
-        }
-        if ( @$book < 2 ) { # first sheet in $book contains meta info
-            $cm->choose( [ $file_dc . ' : no sheets!' ] );
-            return;
+            $sheet_idx = $sheet_idx;
         }
         elsif ( @$book == 2 ) {
             $sheet_idx = 1;
@@ -360,14 +351,14 @@ sub __parse_file {
                 { %{$self->{info}{lyt_stmt_v}}, index => 1, prompt => 'Choose a sheet' }
             );
             if ( ! defined $sheet_idx || ! defined $choices->[$sheet_idx] ) {
-                return;
+                return [];
             }
         }
         if ( $book->[$sheet_idx]{maxrow} == 0 ) {
             my $cm = Term::Choose->new( { %{$self->{info}{lyt_stop}}, prompt => 'Press ENTER' } );
             my $sheet = length $book->[$sheet_idx]{label} ? $book->[$sheet_idx]{label} : 'sheet_' . $_;
             $cm->choose( [ $sheet . ': empty sheet!' ] );
-            return;
+            return [];
         }
         return [ Spreadsheet::Read::rows( $book->[$sheet_idx] ) ], $sheet_idx;
     }
@@ -375,15 +366,16 @@ sub __parse_file {
 
 
 sub __filter_input {
-    my ( $self, $sql, $table, $sql_type, $file, $sheet_idx ) = @_;
+    my ( $self, $sql, $table, $sql_type, $file_or_fh, $sheet_idx ) = @_;
+    return if ! @{$sql->{quote}{insert_into_args}};
     my $auxil = App::DBBrowser::Auxil->new( $self->{info} );
     my $stmt_h = Term::Choose->new( $self->{info}{lyt_stmt_h} );
     #my $backup = clone $sql->{quote}{insert_into_args};
 
     FILTER: while ( 1 ) {
         my @pre = ( undef, $self->{info}{ok} );
-        my ( $input_cols, $input_rows_choose, $input_rows_range, $reset ) = ( 'Columns', 'Rows-choose', 'Rows-range', 'Reset' );
-        my $choices = [ @pre, $input_cols, $input_rows_choose, $input_rows_range, $reset ];
+        my ( $input_cols, $input_rows_choose, $input_rows_range, $cols_to_rows, $reset ) = ( 'Columns', 'Rows-choose', 'Rows-range', 'Cols_to_Rows', 'Reset' );
+        my $choices = [ @pre, $input_cols, $input_rows_choose, $input_rows_range, $cols_to_rows, $reset ];
         $auxil->__print_sql_statement( $sql, $table, $sql_type );
         # Choose
         my $choice = $stmt_h->choose(
@@ -395,8 +387,9 @@ sub __filter_input {
             return;
         }
         elsif ( $choice eq $reset ) {
-            ( $sql->{quote}{insert_into_args} ) = $self->__parse_file( $file, $sheet_idx );
+            ( $sql->{quote}{insert_into_args} ) = $self->__parse_file( $file_or_fh, $sheet_idx );
             #$sql->{quote}{insert_into_args} = clone $backup;
+            next FILTER
         }
         elsif ( $choice eq $self->{info}{ok} ) {
             return;
@@ -448,7 +441,11 @@ sub __filter_input {
         elsif ( $choice eq $input_rows_range ) {
             my $stmt_v = Term::Choose->new( $self->{info}{lyt_stmt_v} );
             my @pre = ( undef );
-            my $choices = [ @pre, map { join ',', @$_ } @{$sql->{quote}{insert_into_args}} ];
+            my $choices;
+            {
+                no warnings 'uninitialized';
+                $choices = [ @pre, map { join ',', @$_ } @{$sql->{quote}{insert_into_args}} ];
+            }
             $auxil->__print_sql_statement( $sql, $table, $sql_type );
             # Choose
             my $first_idx = $stmt_v->choose(
@@ -491,7 +488,11 @@ sub __filter_input {
         elsif ( $choice eq $input_rows_choose ) {
             my $stmt_v = Term::Choose->new( $self->{info}{lyt_stmt_v} );
             my @pre = ( undef );
-            my $choices = [ @pre, map { join ',', @$_ } @{$sql->{quote}{insert_into_args}} ];
+            my $choices;
+            {
+                no warnings 'uninitialized';
+                $choices = [ @pre, map { join ',', @$_ } @{$sql->{quote}{insert_into_args}} ];
+            }
             $auxil->__print_sql_statement( $sql, $table, $sql_type );
             # Choose
             my @idx = $stmt_v->choose(
@@ -505,6 +506,17 @@ sub __filter_input {
             $sql->{quote}{insert_into_args} = [ @{$sql->{quote}{insert_into_args}}[@row_idx] ];
             next FILTER;
         }
+        elsif ( $choice eq $cols_to_rows ) {
+            my $tmp = $sql->{quote}{insert_into_args};
+            my $new = [];
+            for my $i ( 0 .. $#$tmp ) {
+                for my $j ( 0 .. $#{$tmp->[$i]} ) {
+                    $new->[$j][$i] = $tmp->[$i][$j];
+                }
+            }
+            $sql->{quote}{insert_into_args} = $new;
+            next FILTER;
+        }
     }
 }
 
